@@ -19,6 +19,7 @@
 #define FILE_DIALOG_H
 
 #include "config.h"
+#include "libkwavegui_export.h"
 
 #include <QtGlobal>
 #include <QDialog>
@@ -38,7 +39,7 @@ namespace Kwave
      * An improved version of KFileWidget that does not forget the previous
      * directory and pre-selects the previous file extension.
      */
-    class Q_DECL_EXPORT FileDialog: public QDialog
+    class LIBKWAVEGUI_EXPORT FileDialog: public QDialog
     {
         Q_OBJECT
     public:
@@ -72,7 +73,7 @@ namespace Kwave
                    const QString last_ext = QString());
 
         /** Destructor */
-        virtual ~FileDialog() Q_DECL_OVERRIDE
+        virtual ~FileDialog() override
         {
         }
 
@@ -123,12 +124,12 @@ namespace Kwave
 
     signals:
 
-        void filterChanged(const QString &filter);
+        void filterChanged(const KFileFilter &filter);
 
     protected slots:
 
         /** overwritten to call accept() of the KFileWidget and saveConfig() */
-        virtual void accept() Q_DECL_OVERRIDE;
+        void accept() override;
 
         /** save current settings */
         void saveConfig();
