@@ -15,7 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "config.h"
 
 #include <limits>
 
@@ -133,3 +132,5 @@ void Kwave::HMSTimeWidget::disconnect()
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_HMSTimeWidget.cpp"
