@@ -19,6 +19,7 @@
 #define ENCODER_H
 
 #include "config.h"
+#include "libkwave_export.h"
 
 #include <QtGlobal>
 #include <QList>
@@ -35,7 +36,7 @@ namespace Kwave
 
     class MultiTrackReader;
 
-    class Q_DECL_EXPORT Encoder: public QObject, public Kwave::CodecBase
+    class LIBKWAVE_EXPORT Encoder: public QObject, public Kwave::CodecBase
     {
         Q_OBJECT
     public:
@@ -43,7 +44,7 @@ namespace Kwave
         Encoder();
 
         /** Destructor */
-        virtual ~Encoder() Q_DECL_OVERRIDE {}
+        ~Encoder() override {}
 
         /** Returns a new instance of the encoder */
         virtual Encoder *instance() = 0;
